/*
 * FSEnableDebugger2.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.flagstone.transform;

/**
Enables a movie to be debugged when played using the Flash authoring tool, allowing the 
variables defined in the arrays of actions specified in object to be inspected.
 * 
<table class="datasheet">

<tr><th align="left" colspan="2">Attributes</th></tr>

<tr>
<td><a name="FSEnableDebugger2_0">type</a></td>
<td>Identifies the data structure when it is encoded. Read-only.</td>
</tr>

<tr>
<td><a name="FSEnableDebugger2_1">password</a></td>
<td>An MD5 encrypted password.</td>
</tr>

</table>

<p>In order to use the debugger a password must be supplied. When encrypted using the MD5 algorithm it must match the value stored in the password attribute.</p>

<h1 class="datasheet">History</h1>

<p>The FSEnableDebugger2 class represents the EnableDebugger2 data structure introduced in Flash 6. It replaced EnableDebugger in Flash 5 with a different format to support internal changes in the Flash Player. The functionality was not changed.</p>
 */  
public class FSEnableDebugger2 extends FSMovieObject
{
    private String password = null;
        
    /**
     * Construct an FSEnableDebugger2 object, initalizing it with values decoded 
     * from an encoded object.
     * 
     * @param coder an FSCoder containing the binary data.
     */
    public FSEnableDebugger2(FSCoder coder)
    {
        super(EnableDebugger2);
        decode(coder);
    }
    /** 
     * Constructs an FSEnableDebugger2 object with an MD5 encrypted password.
     *
     * @param password the string defining the password.
     */
    public FSEnableDebugger2(String password)
    {
        super(EnableDebugger2);
        setPassword(password);
    }
    /**
     * Constructs an FSEnableDebugger2 object by copying values from an existing 
     * object.
     *
     * @param obj an FSEnableDebugger2 object.
     */
    public FSEnableDebugger2(FSEnableDebugger2 obj)
    {
        super(obj);
        password = new String(obj.password);
    }    

    /** Gets the MD5 encrypted password.

        @return the string defining the password.
        */
    public String getPassword() { return password; }

    /** Sets the MD5 encrypted password.

        @param aString the string defining the password.
        */
    public void setPassword(String aString)
    {
        password = aString;
    }

    public boolean equals(Object anObject)
    {
        boolean result = false;
        
        if (super.equals(anObject))
        {
            FSEnableDebugger2 typedObject = (FSEnableDebugger2)anObject;
            
            if (password != null)
                result = password.equals(typedObject.password);
            else
                result = typedObject.password == null;
        }
        return result;
    }

    public void appendDescription(StringBuffer buffer, int depth)
    {
        buffer.append(name());
        
        if (depth > 0)
        {
            buffer.append(": { ");
            Transform.append(buffer, "password", password);
            buffer.append("}");
        }
    }

     public int length(FSCoder coder)
    {
        super.length(coder);

        length += 2 + coder.strlen(password, true);
            
        return length;
    }
    
    public void encode(FSCoder coder)
    {
        super.encode(coder);
        
        coder.writeWord(0, 2);
        coder.writeString(password);
        coder.writeWord(0, 1);
        
        coder.endObject(name());
    }
    
    public void decode(FSCoder coder)
    {
        super.decode(coder);

        coder.readWord(2, false);
        password = coder.readString();
        
        coder.endObject(name());
    }
}
