/*
 * FSProperty.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd.. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.flagstone.transform;

/**
 * FSProperty is a lightweigth class used to hold codes that specify movie clip 
 * and movie properties that will be pushed onto the Flash Player stack.
 * 
 * See FSPush for a list of available properties.
 */
public class FSProperty extends FSTransformObject
{
    private int value = 0;

    /**
     * Construct an FSProperty object, initalizing it with values decoded from
     * an encoded object.
     * 
     * @param coder an FSCoder containing the binary data.
     */
    public FSProperty(FSCoder coder)
    {
        decode(coder);
    }
    /**
     * Construct an FSProperty object with the proerty value.
     * 
     * @param aValue an integer representing a movie property.
     */
    public FSProperty(int aValue)
    {
        setValue(aValue);
    }
    /**
     * Constructs an FSProperty object by copying values from an existing 
     * object.
     *
     * @param obj an FSProperty object.
     */
    public FSProperty(FSProperty obj)
    {
        value = obj.value;
    }    

    public int getValue() 
    {
        return value;
    }

    public void setValue(int aValue) 
    {
        value = aValue;
    }

    public boolean equals(Object anObject)
    {
        boolean result = false;
        
        if (super.equals(anObject))
            result = value == ((FSProperty)anObject).getValue();

        return result;
    }

    public void appendDescription(StringBuffer buffer, int depth)
    {
        buffer.append(name());
        
        if (depth > 0)
        {
            buffer.append(": { ");
            Transform.append(buffer, "value", value);
            buffer.append("}");
        }
    }

    public int length(FSCoder coder)
    { 
        return 5;
    }
        
    public void encode(FSCoder coder) 
    {
        coder.writeWord(1, 1);
        coder.writeWord(value, 4);
    }
    
    public void decode(FSCoder coder)
    {
        /* type */ coder.readWord(1, false);
        value = coder.readWord(4, false);
    }
}
