/*
 * FSRemoveObject2.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.flagstone.transform;

/**
FSRemoveObject2 removes an object from the display list.

<table class="datasheet">

<tr><th align="left" colspan="2">Attributes</th></tr>

<tr>
<td><a name="FSRemoveObject2_0">type</a></td>
<td>Identifies the data structure when it is encoded. Read-only.</td>
</tr>

<tr>
<td><a name="FSRemoveObject2_1">layer</a></td>
<td>The number of the layer in the Flash Player's Display List where the object is displayed.</td>
</tr>

</table>

<p>The FSRemoveObject2 class only requires the layer number to identify a particular object, unlike the FSRemoveObject class which also requires the object's identifier although only one object can be placed on a given layer.</p>

<h1 class="datasheet">History</h1>

<p>The FSRemoveObject2 class represents the RemoveObject2 tag from the Macromedia Flash (SWF) File Format Specification. It was introduced in Flash in Flash 3.</p>
 */ 
public class FSRemoveObject2 extends FSMovieObject
{
    private int layer = 0;

    /**
     * Construct an FSRemoveObject2 object, initalizing it with values decoded 
     * from an encoded object.
     * 
     * @param coder an FSCoder containing the binary data.
     */
    public FSRemoveObject2(FSCoder coder)
    {
        super(RemoveObject2);
        decode(coder);
    }
    /** Constructs an FSRemoveObject2, specifying the layer in the display list where the object to be removed is currently displayed.

        @param layer the layer number on which the object is displayed.
        */
    public FSRemoveObject2(int layer)
    {
        super(RemoveObject2);
        setLayer(layer);
    }
    /**
     * Constructs an FSRemoveObject2 object by copying values from an existing 
     * object.
     *
     * @param obj an FSRemoveObject2 object.
     */
    public FSRemoveObject2(FSRemoveObject2 obj)
    {
        super(obj);
        layer = obj.layer;
    }    

    /** Gets the layer in the display list where the object to be removed is currently displayed.

        @return the layer number where the object is currently displayed.
        */
    public int getLayer() { return layer; }

    /** Sets the layer in the display list from which the object will be removed.

        @param aLayer the layer number on which the object is displayed.
        */
    public void setLayer(int aLayer)
    {
        layer = aLayer;
    }

    public boolean equals(Object anObject)
    {
        boolean result = false;
        
        if (super.equals(anObject))
        {
            FSRemoveObject2 typedObject = (FSRemoveObject2)anObject;
            
            result = layer == typedObject.layer;
        }
        return result;
    }

    public void appendDescription(StringBuffer buffer, int depth)
    {
        buffer.append(name());
        
        if (depth > 0)
        {
            buffer.append(": { ");
            Transform.append(buffer, "layer", layer);
            buffer.append("}");
        }
    }

    public int length(FSCoder coder)
    {
        super.length(coder);
        length += 2;

        return length;
    }
    
    public void encode(FSCoder coder)
    {
        super.encode(coder);
        coder.writeWord(layer, 2);
        coder.endObject(name());
    }
    
    public void decode(FSCoder coder)
    {
        super.decode(coder);
        layer = coder.readWord(2, false);
        coder.endObject(name());
    }
}
