/*
 * FSSetBackgroundColorTest.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.flagstone.transform.test;

import com.flagstone.transform.*;

public class FSSetBackgroundColorTest extends FSClassTest
{    
    private static FSColor[] colours = new FSColor[] {
        new FSColor(  0,   0,   0),
        new FSColor(255,   0,   0),
        new FSColor(255, 255,   0),
        new FSColor(  0, 255,   0),
        new FSColor(  0, 255, 255),
        new FSColor(  0,   0, 255),
        new FSColor(255,   0, 255),
        new FSColor(255, 255, 255),
    };
           
    private static int[][] encodedObjects = new int[][] {
        { 0x43, 0x02, 0x00, 0x00, 0x00 }, 
        { 0x43, 0x02, 0xFF, 0x00, 0x00 }, 
        { 0x43, 0x02, 0xFF, 0xFF, 0x00 }, 
        { 0x43, 0x02, 0x00, 0xFF, 0x00 }, 
        { 0x43, 0x02, 0x00, 0xFF, 0xFF }, 
        { 0x43, 0x02, 0x00, 0x00, 0xFF }, 
        { 0x43, 0x02, 0xFF, 0x00, 0xFF }, 
        { 0x43, 0x02, 0xFF, 0xFF, 0xFF }, 
    };
    
    /**
     * @testng.test groups="setbackgroundcolor, constructors"
     */
    public void checkConstructors()
    {
        for (int i=0; i<colours.length; i++)
        {
            FSSetBackgroundColor background = new FSSetBackgroundColor(colours[i]);
            
            checkType(FSMovieObject.SetBackgroundColor, background.getType());
            checkEqual(colours[i], background.getColor());
        }
    }
    /**
     * @testng.test groups="setbackgroundcolor, constructors"
     */
    public void checkCopyConstructor()
    {
        for (int i=0; i<colours.length; i++)
        {
            FSSetBackgroundColor original = new FSSetBackgroundColor(colours[i]);
            FSSetBackgroundColor copy = new FSSetBackgroundColor(original);
            
            checkEqual(colours[i], copy.getColor());
            checkNotIdentical(colours[i], copy.getColor());
        }
    }
    /**
     * @testng.test groups="setbackgroundcolor, constructors"
     */
    public void checkContainsReference()
    {
        FSColor colour = new FSColor(0, 0, 0);
        FSSetBackgroundColor background = new FSSetBackgroundColor(colour);
        
        checkIdentical(colour, background.getColor());
    }
    /**
     * @testng.test groups="setbackgroundcolor, constructors"
     */
    public void checkClone()
    {
        FSColor colour = new FSColor(0, 0, 0);
        FSSetBackgroundColor background = new FSSetBackgroundColor(colour);
        FSSetBackgroundColor clone = (FSSetBackgroundColor)background.clone();
        
        checkEqual(background, clone);
        checkNotIdentical(background, clone);
    }
    /**
     * @testng.test groups="setbackgroundcolor, accessors"
     */
    public void checkAccessors()
    {
        FSSetBackgroundColor background = new FSSetBackgroundColor(new FSColor(-1, -1, -1));
        
        for (int i=0; i<colours.length; i++)
        {
            background.setColor(colours[i]);
            checkEqual(colours[i], background.getColor());
        }
    }
    /**
     * @testng.test groups="setbackgroundcolor, utilities"
     */
    public void checkEquals()
    {
        for (int i=0; i<colours.length; i++)
        {
            FSSetBackgroundColor a = new FSSetBackgroundColor(colours[i]);
            FSSetBackgroundColor b = new FSSetBackgroundColor(colours[i]);
            
            checkEqual(a, b);
        }
    }
    /**
     * @testng.test groups="setbackgroundcolor, encode"
     */
    public void checkEncode()
    {
        for (int i=0; i<encodedObjects.length; i++) {
            checkEncode(new FSSetBackgroundColor(colours[i]), encodedObjects[i]);
        }
    }
    /**
     * @testng.test groups="setbackgroundcolor, decode"
     */
    public void checkDecode()
    {       
        for (int i=0; i<encodedObjects.length; i++) 
        {
            FSCoder coder = new FSCoder(FSCoder.LITTLE_ENDIAN, compact(encodedObjects[i]));            
            FSSetBackgroundColor background = new FSSetBackgroundColor(coder);

            checkDecode(coder, encodedObjects[i].length);
            checkType(FSMovieObject.SetBackgroundColor, background.getType());
            checkEqual(colours[i], background.getColor());
        }
    }
}
