/*
 * FSSetBackgroundColorTest.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.flagstone.transform.test;

import com.flagstone.transform.*;

public class FSShowFrameTest extends FSClassTest
{    
    private static int[][] encodedObjects = new int[][] {
        { 0x40, 0x00 }, 
    };
    
    /**
     * @testng.test groups="showframe, constructors"
     */
    public void checkConstructors()
    {
        FSShowFrame obj = new FSShowFrame();
        
        checkType(FSMovieObject.ShowFrame, obj.getType());
    }
    /**
     * @testng.test groups="showframe, constructors"
     */
    public void checkCopyConstructor()
    {
        FSShowFrame original = new FSShowFrame();
        FSShowFrame copy = new FSShowFrame(original);
        
        checkEqual(original, copy);
        checkNotIdentical(original, copy);
    }
    /**
     * @testng.test groups="showframe, constructors"
     */
    public void checkClone()
    {
        FSShowFrame original = new FSShowFrame();
        FSShowFrame clone = (FSShowFrame)original.clone();
        
        checkEqual(original, clone);
        checkNotIdentical(original, clone);
    }
    /**
     * @testng.test groups="showframe, utilities"
     */
    public void checkEquals()
    {
        FSShowFrame a = new FSShowFrame();
        FSShowFrame b = new FSShowFrame();
        
        checkEqual(a, b);
    }
    /**
     * @testng.test groups="showframe, encode"
     */
    public void checkEncode()
    {
        for (int i=0; i<encodedObjects.length; i++) {
            checkEncode(new FSShowFrame(), encodedObjects[i]);
        }
    }
    /**
     * @testng.test groups="showframe, decode"
     */
    public void checkDecode()
    {       
        for (int i=0; i<encodedObjects.length; i++) 
        {
            FSCoder coder = new FSCoder(FSCoder.LITTLE_ENDIAN, compact(encodedObjects[i]));            
            FSShowFrame obj = new FSShowFrame(coder);

            checkDecode(coder, encodedObjects[i].length);
            checkType(FSMovieObject.ShowFrame, obj.getType());
        }
    }
}
