/*
 * TextDumpTest.java
 * Transform
 * 
 * Copyright (c) 2001-2006 Flagstone Software Ltd. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Flagstone Software Ltd. nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.flagstone.transform.test;

import java.io.*;

import com.flagstone.transform.tools.*;

public class TextDumpTest
{
    private File sourceDir = null;
    private File destDir = null;
    private String extension = ".swf";
    
    public TextDumpTest()
    {
    }
    /**
     * @testng.configuration beforeTest = "true" alwaysRun = "true" 
     * @testng.parameters value = "srcDir dstDir"
     */
    public void configure(String srcDir, String dstDir)
    {
        sourceDir = new File(srcDir);
        destDir = new File(dstDir);
    }
    /**
     * @testng.test dataProvider="files"
     */
    public void toText(String file)
    {
        try
        {
            File srcFile = new File(sourceDir, file);
            File dstFile = new File(destDir, file.substring(0, file.length()-3)+"txt");
            
            if (destDir.exists() == false)
                assert destDir.mkdirs() : "Count not create directory: "+destDir;
            
            new TextDump(new String[] {
                            "--fileIn", srcFile.getPath(), 
                            "--fileOut", dstFile.getPath()});
        }
        catch (Throwable e)
        {
            assert false : file+": "+e.toString();
        }
    }
    /**
     * @testng.data-provider name="files"
     */
    public Object[][] findFiles()
    {
        FilenameFilter filter = new FilenameFilter() 
        {
            public boolean accept(File directory, String name) {
                return name.endsWith(extension);
            }
        };
        
        String[] files = sourceDir.list(filter);       

        Object[][] parameters = new Object[files.length][1];
        
        for (int i=0; i<files.length; i++)
            parameters[i] = new Object[] { files[i] };
        
        return parameters;
    }
}
